@@ -46,6 +46,9 @@ __all__ = [
     "range",
     "cast",
     "identity",
+    "round",
+    "floor",
+    "ceil",
     "negative",
     "abs",
     "sign",
@@ -247,22 +250,25 @@ class ActiveDevice:
 
     def __init__(self, name):
         self.name = name
+        self._previous_active_name = None
         self._active_tf_manager = None
 
     def __enter__(self):
-        # Set active name.
-        ActiveDevice.active_name = self.name
-
-        # Activate the TF device manager, if it is available.
+        # Activate the TF device manager, if it is available. We do this first: if it
+        # errors, `active_name` remains unchanged.
         if ActiveDevice._tf_manager:
             self._active_tf_manager = ActiveDevice._tf_manager(self.name)
             self._active_tf_manager.__enter__()
 
+        # Set active name.
+        self._previous_active_name = ActiveDevice.active_name
+        ActiveDevice.active_name = self.name
+
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
         # Unset the active name.
-        ActiveDevice.active_name = None
+        ActiveDevice.active_name = self._previous_active_name
 
         # Exit the TF device manager, if it was entered.
         if self._active_tf_manager:
@@ -563,7 +569,7 @@ def cast(dtype: Numeric, a: DType):  # pragma: no cover
 @dispatch
 @abstract()
 def identity(a: Numeric):  # pragma: no cover
-    """Identity function
+    """Identity function.
 
     Args:
         a (tensor): Tensor.
@@ -573,6 +579,45 @@ def identity(a: Numeric):  # pragma: no cover
     """
 
 
+@dispatch
+@abstract()
+def round(a: Numeric):  # pragma: no cover
+    """Round a tensor to whole numbers.
+
+    Args:
+        a (tensor): Tensor.
+
+    Returns:
+        tensor: `a` rounded to whole numbers.
+    """
+
+
+@dispatch
+@abstract()
+def floor(a: Numeric):  # pragma: no cover
+    """Round a tensor down to whole numbers.
+
+    Args:
+        a (tensor): Tensor.
+
+    Returns:
+        tensor: `a` rounded down to whole numbers.
+    """
+
+
+@dispatch
+@abstract()
+def ceil(a: Numeric):  # pragma: no cover
+    """Round a tensor up to whole numbers.
+
+    Args:
+        a (tensor): Tensor.
+
+    Returns:
+        tensor: `a` rounded up to whole numbers.
+    """
+
+
 @dispatch
 @abstract()
 def negative(a: Numeric):  # pragma: no cover
