@@ -93,6 +93,21 @@ def identity(a: Numeric):
     return np.array(a)
 
 
+@dispatch
+def round(a: Numeric):
+    return np.round(a)
+
+
+@dispatch
+def floor(a: Numeric):
+    return np.floor(a)
+
+
+@dispatch
+def ceil(a: Numeric):
+    return np.ceil(a)
+
+
 @dispatch
 def negative(a: Numeric):
     return np.negative(a)
