@@ -19,6 +19,11 @@ def matmul(a: Numeric, b: Numeric, tr_a: bool = False, tr_b: bool = False):
     return torch.matmul(a, b)
 
 
+@dispatch
+def einsum(equation: str, *elements: Numeric):
+    return torch.einsum(equation, *elements)
+
+
 @dispatch
 def transpose(a: Numeric, perm: Optional[Union[tuple, list]] = None):
     # Correctly handle special cases.
